@@ -1,15 +1,29 @@
 // Swarm library. Copyright  1996-2000 Swarm Development Group.
-// This library is distributed without any warranty; without even the
-// implied warranty of merchantability or fitness for a particular purpose.
-// See file LICENSE for details and terms of copying.    
+// This program is free software; you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation; either version 2 of the License, or
+// (at your option) any later version.
+//
+// This program is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+// General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with this program; if not, write to the Free Software
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+// USA
+// 
+// The Swarm Development Group can be reached via our website at:
+// http://www.swarm.org/    
 
 //S: General simulation tools
 
 //D: A collection of tools that are only loosely related to each other.
 //D: the class hierarchy is virtually flat.
 
+#import <swarm.h>
 #import <objectbase.h>
-#include <externvar.h>
 
 @protocol UName <SwarmObject, CREATABLE>
 //S: A class used to generate unique names (e.g. "critter1", "critter2" etc.)
@@ -427,9 +441,6 @@ USING
               APPNAME_STRING, \
               version, bugAddress, argumentsClass, NULL, NULL, NO, NO)
 
-//G: Flag for whether we're in graphics mode or not.  Default is NO.
-externvar BOOL swarmGUIMode;
-
 @class ControlPanel;
 @class UName;
 @class InFile;
